@@ -10,7 +10,7 @@ String::License - detect source code license statements in a text string
 
 =head1 VERSION
 
-Version v0.0.1
+Version v0.0.2
 
 =head1 SYNOPSIS
 
@@ -33,7 +33,7 @@ and serializes them in a normalized format.
 
 =cut
 
-package String::License v0.0.1;
+package String::License v0.0.2;
 
 use Carp            qw(croak);
 use Log::Any        ();
@@ -45,6 +45,8 @@ use Regexp::Pattern 0.2.12;
 use String::License::Naming::Custom;
 use String::License::Naming::SPDX;
 
+use namespace::clean;
+
 class Trait {
 	field $log;
 	field $name :param;
@@ -179,8 +181,6 @@ class Grant {
 
 class String::License;
 
-use namespace::clean qw(-except new);
-
 # try enable RE2 engine
 eval { require re::engine::RE2 };
 my @OPT_RE2 = $@ ? () : ( engine => 'RE2' );
